@@ -42,11 +42,13 @@ public:
     ///
     /// \brief Write points to an opened file
     /// \param f Already opened fstream file with write access
+    /// \param scaleFactor The factor to scale the data with
     ///
     /// Write all the points to a file by calling sequentially the write method of each point
     ///
     void write(
-            std::fstream &f) const;
+            std::fstream &f,
+            float scaleFactor) const;
 
 
     //---- POINT ----//
